@@ -1,19 +1,19 @@
 from datetime import datetime, date
 from typing import List, Optional
 from uuid import UUID
-from dapodik.base import dataclass, field, freeze
+import attr
 
 
-@dataclass
+@attr.dataclass
 class PesertaDidik:
-    peserta_didik_id: UUID = freeze(default="Admin.model.PesertaDidik-1")
-    nama: str = freeze()
-    jenis_kelamin: str = freeze()
-    nisn: str = freeze(default="")
-    nik: str = freeze(default="")
-    no_kk: str = ""
-    tempat_lahir: str = freeze()
-    tanggal_lahir: date = freeze()
+    peserta_didik_id: UUID
+    nama: str
+    jenis_kelamin: str
+    nisn: str
+    nik: str
+    no_kk: str
+    tempat_lahir: str
+    tanggal_lahir: date
     agama_id: int
     kebutuhan_khusus_id: int
     alamat_jalan: str
@@ -22,39 +22,39 @@ class PesertaDidik:
     nama_dusun: str
     desa_kelurahan: str
     kode_wilayah: str
-    kode_pos: Optional[int] = None
-    lintang: str = "0"
-    bujur: str = "0"
-    jenis_tinggal_id: int = 1
-    alat_transportasi_id: int = 1
+    kode_pos: Optional[int]
+    lintang: str
+    bujur: str
+    jenis_tinggal_id: int
+    alat_transportasi_id: int
     nik_ayah: str
     nik_ibu: str
-    anak_keberapa: int = 1
+    anak_keberapa: int
     nik_wali: Optional[str]
     nomor_telepon_rumah: Optional[str]
     nomor_telepon_seluler: Optional[str]
-    email: Optional[str] = ""
-    penerima_kps: int = 0
-    no_kps: Optional[str] = None
-    layak_pip: int = 0
-    penerima_kip: int = 0
-    no_kip: Optional[str] = None
-    nm_kip: Optional[str] = None
-    no_kks: Optional[str] = None
-    reg_akta_lahir: str = ""
-    id_layak_pip: Optional[int] = None
-    id_bank: Optional[int] = freeze(default=None)
-    rekening_bank: Optional[str] = freeze(default=None)
-    nama_kcp: Optional[str] = freeze(default=None)
-    rekening_atas_nama: Optional[str] = freeze(default=None)
-    status_data: Optional[int] = freeze(default=None)
+    email: Optional[str]
+    penerima_kps: int
+    no_kps: Optional[str]
+    layak_pip: int
+    penerima_kip: int
+    no_kip: Optional[str]
+    nm_kip: Optional[str]
+    no_kks: Optional[str]
+    reg_akta_lahir: str
+    id_layak_pip: Optional[int]
+    id_bank: Optional[int]
+    rekening_bank: Optional[str]
+    nama_kcp: Optional[str]
+    rekening_atas_nama: Optional[str]
+    status_data: Optional[int]
     nama_ayah: str
     tahun_lahir_ayah: int
     jenjang_pendidikan_ayah: int
     pekerjaan_id_ayah: int
     penghasilan_id_ayah: int
     kebutuhan_khusus_id_ayah: int
-    nama_ibu_kandung: str = freeze()
+    nama_ibu_kandung: str
     tahun_lahir_ibu: int
     jenjang_pendidikan_ibu: int
     penghasilan_id_ibu: int
@@ -65,16 +65,16 @@ class PesertaDidik:
     jenjang_pendidikan_wali: int
     pekerjaan_id_wali: int
     penghasilan_id_wali: int
-    kewarganegaraan: str = field(default="ID")
-    registrasi_id: UUID = freeze()
-    jurusan_sp_id: Optional[str] = freeze()
-    sekolah_id: UUID = freeze()
+    kewarganegaraan: str
+    registrasi_id: UUID
+    jurusan_sp_id: Optional[str]
+    sekolah_id: UUID
     jenis_pendaftaran_id: int
     nipd: int
     tanggal_masuk_sekolah: date
     jenis_keluar_id: Optional[int]
     tanggal_keluar: Optional[datetime]
-    keterangan: str = freeze()
+    keterangan: str
     no_skhun: Optional[str]
     no_peserta_ujian: Optional[str]
     no_seri_ijazah: Optional[str]
@@ -88,25 +88,25 @@ class PesertaDidik:
     ket_keluar: Optional[str]
     anggota_rombel_id: Optional[UUID]
     tingkat_pendidikan_id: Optional[int]
-    rombel_saat_ini: str = freeze(default=None)
-    rombel: str = freeze(default=None)
-    id_bank_str: Optional[str] = freeze(default=None)
-    kewarganegaraan_str: str = ""
+    rombel_saat_ini: str
+    rombel: str
+    id_bank_str: Optional[str]
+    kewarganegaraan_str: str
     nomor_induk_pd: int
-    yatim_piatu: bool = False
-    konfirmasi_mutasi: int = freeze(default=0)
-    vld_count: Optional[int] = freeze(default=0)
+    yatim_piatu: bool
+    konfirmasi_mutasi: int
+    vld_count: Optional[int]
     # Metadata
-    create_date: Optional[datetime] = freeze(default=None)
-    last_update: Optional[datetime] = freeze(default=None)
-    soft_delete: Optional[int] = freeze(default=None)
-    last_sync: Optional[datetime] = freeze(default=None)
-    updater_id: Optional[UUID] = freeze(default=None)
+    create_date: Optional[datetime] = None
+    last_update: Optional[datetime] = None
+    soft_delete: Optional[int] = None
+    last_sync: Optional[datetime] = None
+    updater_id: Optional[UUID] = None
 
     def __str__(self):
         return self.nama
 
-    @dataclass
+    @attr.dataclass(kw_only=True)
     class Create:
         nama: str
         jenis_kelamin: str
@@ -190,6 +190,6 @@ class PesertaDidik:
         nomor_telepon_rumah: str = ""
         nomor_telepon_seluler: str = ""
         email: str = ""
-        kebutuhan_khusus_id_selector: List[int] = field(factory=list)
-        kebutuhan_khusus_id_selector_ayah: List[int] = field(factory=list)
-        kebutuhan_khusus_id_selector_ibu: List[int] = field(factory=list)
+        kebutuhan_khusus_id_selector: List[int] = attr.ib(factory=list)
+        kebutuhan_khusus_id_selector_ayah: List[int] = attr.ib(factory=list)
+        kebutuhan_khusus_id_selector_ibu: List[int] = attr.ib(factory=list)
