@@ -1,8 +1,4 @@
 from attr import Attribute
-from cachetools import cachedmethod as cachem
-from cachetools.keys import hashkey
-from functools import partial, wraps
-from operator import attrgetter
 from typing import Any, List, Tuple, Type, TypeVar, Union
 from .get_subtypes import _get_subtypes
 
@@ -34,8 +30,3 @@ def from_list(t: Type[T], datas: List[dict]) -> List[T]:
     for data in datas:
         results.append(from_dict(t, data))
     return results
-
-
-def cachedmethod(func):
-    key = func.__name__
-    return wraps(func)(cachem(attrgetter("cache"), key=partial(hashkey, key)))
